% dlg_eyetrackerica - pops user dialogue, called by pop_eyetrackerica.m
%                see >> help pop_eyetrackerica
%
% Copyright (C) 2009-2013 Olaf Dimigen & Ulrich Reinacher, HU Berlin
% olaf.dimigen@hu-berlin.de / ulrich.reinacher.1@hu-berlin.de

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, 51 Franklin Street, Boston, MA 02110-1301, USA

function [sacstring, fixstring, tolerance, maxratio, flagmode, plotfig, topomode] = dlg_eyetrackerica(callingFcn,EEG)

geometry = { 1 [2 1.3 0.4] [2 1.3 0.4] [2 1.3 0.4] [2 1.3 0.4] 1 1 [2 1.3 0.4] 1 1 [2 1.7] 1 1 [2 1.7] [2 1.7]};

%% callbacks
cbevent1 = ['if ~isfield(EEG.event, ''type'')' ...
    '   errordlg2(''No type field'');' ...
    'else' ...
    '   if isnumeric(EEG.event(1).type),' ...
    '        [tmps,tmpstr] = pop_chansel(unique([ EEG.event.type ]));' ...
    '   else,' ...
    '        [tmps,tmpstr] = pop_chansel(unique({ EEG.event.type }));' ...
    '   end;' ...
    '   if ~isempty(tmps)' ...
    '       set(findobj(''parent'', gcbf, ''tag'', ''sevent''), ''string'', tmpstr);' ...
    '   end;' ...
    'end;' ...
    'clear tmps tmpv tmpstr tmpfieldnames;' ];

cbevent2 = ['if ~isfield(EEG.event, ''type'')' ...
    '   errordlg2(''No type field'');' ...
    'else' ...
    '   if isnumeric(EEG.event(1).type),' ...
    '        [tmps,tmpstr] = pop_chansel(unique([ EEG.event.type ]));' ...
    '   else,' ...
    '        [tmps,tmpstr] = pop_chansel(unique({ EEG.event.type }));' ...
    '   end;' ...
    '   if ~isempty(tmps)' ...
    '       set(findobj(''parent'', gcbf, ''tag'', ''fevent''), ''string'', tmpstr);' ...
    '   end;' ...
    'end;' ...
    'clear tmps tmpv tmpstr tmpfieldnames;' ];

flagoptions = {'1. Test mode, flag nothing'; '2. Flag bad components, add to existing flags'; '3. Flag bad components, overwrite existing flags'};
topooptions = {'1. bad & good components';'2. bad components';'3. good components';'4. do not plot topos'};

%% main menu
uilist = {...
    {'style', 'text', 'string', 'Define saccade & fixation intervals', 'fontweight','bold'},...
    ...
    {'style', 'text', 'string', 'Saccade event:'},...
    {'style', 'edit', 'string', 'saccade', 'tag', 'sevent' },...
    {'style', 'pushbutton', 'string', '...', 'callback', cbevent1}, ...
    ...
    {'style', 'text', 'string', 'Fixation event:'},...
    {'style', 'edit', 'string', 'fixation', 'tag', 'fevent' }, ...
    {'style', 'pushbutton', 'string', '...', 'callback', cbevent2}, ...
    ...
    {'style', 'text', 'string', 'Extra time before saccade onset:'},...
    {'style', 'edit', 'string', '10' 'tag', 'tolerance1'},...
    {'style', 'text', 'string', 'ms'},...
    ...
    {'style', 'text', 'string', 'Extra time after saccade offset:'},...
    {'style', 'edit', 'string', '10' 'tag', 'tolerance2'},...
    {'style', 'text', 'string', 'ms'},...
    {},...
    {'style', 'text', 'string', 'Set threshold for saccade/fixation variance ratio','fontweight','bold'},...
    {'style', 'text', 'string', 'Flag components with ratio above:'},...
    {'style', 'edit', 'string', '1.1', 'tag', 'ratio' },...
    {'style', 'text', 'string', ''},...
    {},...
    {'style', 'text', 'string', 'Rejection options','fontweight','bold'},...
    {'style', 'text', 'string', 'Flag bad components in EEG.reject?'},...
    {'Style', 'popupmenu', 'string', flagoptions,'tag','flagmode','value',3},...
    {},...
    {'style', 'text', 'string', 'Plotting options','fontweight','bold'},...
    {'style', 'text', 'string', 'Show plot with variance ratios?'},...
    {'style', 'checkbox', 'value', 1, 'tag','plotfig'}, ...
    {'style', 'text', 'string', 'Show topographies of flagged ICs?'},...
    {'Style', 'popupmenu', 'string', topooptions,'tag','topomode','value',1},...
    };


%% make GUI
[results tmp tmp outstruct] = inputgui( 'geometry',geometry, ...
    'uilist',uilist,'helpcom', ['pophelp(''' callingFcn ''');'],...
    'title', ['Flag ICs based on covariance with eye tracker -- ', callingFcn]);


%% process user input (cancel)
if isempty(results)
    return
end

%% collect dialogue entries
sacstring    = outstruct.sevent;
fixstring    = outstruct.fevent;
tolerance(1) = round(str2num(outstruct.tolerance1)/(1000/EEG.srate));
tolerance(2) = round(str2num(outstruct.tolerance2)/(1000/EEG.srate));
maxratio     = str2num(outstruct.ratio);
flagmode     = outstruct.flagmode;
plotfig      = outstruct.plotfig;
topomode     = outstruct.topomode;

end