function y = smoothdata(xx)
%------------------------------------------------------------
%
%  FUNCTION vecvel.m
%  Calculation of eye velocity from position data
%  Please cite: Engbert, R., & Kliegl, R. (2003) Microsaccades
%  uncover the orientation of covert attention. Vision Research
%  43: 1035-1045.
%  Engbert, R., & Mergenthaler, K. (2006) Microsaccades 
%  are triggered by low retinal image slip. Proceedings of the 
%  National Academy of Sciences of the United States of America, 
%  103: 7192-7197.
%
%  (Version 1.2, 01 JAN 2012)
%-------------------------------------------------------------
%
%  INPUT:
%  xy(1:N,1:2)     raw data, x- and y-components of the time series
%
%  OUTPUT:
%  v(1:N,1:2)      smoothed x- and y-components
%
%-------------------------------------------------------------
y0 = xx(1,:);
N = length(xx); 
v = zeros(N,2);
v(3:N-2,:) = 1/6*[xx(5:end,:) + xx(4:end-1,:) - xx(2:end-3,:) - xx(1:end-4,:)];
v(2,:) = 1/2*[xx(3,:) - xx(1,:)];
v(N-1,:) = 1/2*[xx(end,:) - xx(end-2,:)];
y = cumsum([y0; v]);

